==> hlint-2.1.14-87-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.1.14
id: hlint-2.1.14-Gylj9qoMi6AIEvgAxCM4rD
key: hlint-2.1.14-Gylj9qoMi6AIEvgAxCM4rD
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
abi: 4e6419f3511919a22ad341c990c929fc
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Timing CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.1.14-Gylj9qoMi6AIEvgAxCM4rD
depends:
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 cpphs-1.20.8-ISt2D5MEyRI4QQUGFRtm5S
    data-default-0.7.1.1-BJebZgJOe7bK46yzXrFmEt directory-1.3.3.0
    extra-1.6.18-C8rpwMjbnSZ7dBHvBfZVKs filepath-1.4.2.1
    haskell-src-exts-1.21.1-Knj2Sf32FhF4mJrXgorIEK
    haskell-src-exts-util-0.2.5-AofDedq1ciG53lJ8hyaCY8
    hscolour-1.24.4-BEI90NJLSwF5tw227AM1ae process-1.6.5.0
    refact-0.3.0.2-1sV84vP3OHo15p4d2xAoYA text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-728qixY9X6X7DLfIoKBNaj
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.2.0-alxzflql864nfC2SW5pb6
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-2.1.14-88-x86_64.pkg.tar.xz: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 2.1.14
id: hlint-2.1.14-7ADrWE1vlGn1tP84tfmL5c
key: hlint-2.1.14-7ADrWE1vlGn1tP84tfmL5c
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
abi: 47349e8381c74376ccd8ea612175fe5c
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Timing CC Config.Compute Config.Haskell
                Config.Read Config.Type Config.Yaml HSE.All HSE.Match HSE.Reduce
                HSE.Scope HSE.Type HSE.Unify HSE.Util Hint.All Hint.Bracket
                Hint.Comment Hint.Duplicate Hint.Export Hint.Extensions Hint.Import
                Hint.Lambda Hint.List Hint.ListRec Hint.Match Hint.Monad
                Hint.Naming Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict
                Hint.Type Hint.Unsafe Hint.Util Test.All Test.Annotations
                Test.InputOutput Test.Proof Test.Translate Test.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/hlint-2.1.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hlint
hs-libraries: HShlint-2.1.14-7ADrWE1vlGn1tP84tfmL5c
depends:
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 cpphs-1.20.8-ISt2D5MEyRI4QQUGFRtm5S
    data-default-0.7.1.1-BJebZgJOe7bK46yzXrFmEt directory-1.3.3.0
    extra-1.6.18-C8rpwMjbnSZ7dBHvBfZVKs filepath-1.4.2.1
    haskell-src-exts-1.21.1-Knj2Sf32FhF4mJrXgorIEK
    haskell-src-exts-util-0.2.5-AofDedq1ciG53lJ8hyaCY8
    hscolour-1.24.4-BEI90NJLSwF5tw227AM1ae process-1.6.5.0
    refact-0.3.0.2-1sV84vP3OHo15p4d2xAoYA text-1.2.3.1
    transformers-0.5.6.2 uniplate-1.6.12-728qixY9X6X7DLfIoKBNaj
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.2.0-kwMBXLDeksBUKCXUxlQ5
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
